---
name: Bug report
about: Create a report to help us reproduce and fix a bug
title: "[BUG]"
labels: ['bug']
assignees: ''

---

**Bug report checklist**
<!-- Please ensure at least one of the following to help the developers troubleshoot the problem:  -->
- [ ] I provided code that demonstrates a minimal reproducible example. <!-- Ideal, especially via source install -->
- [ ] I confirmed bug exists on the latest mainline of `rk-transformers` via source install. <!-- Preferred -->

**Describe the bug**
<!-- A clear and concise description of what the bug is. -->

**Expected behavior**
<!-- A clear and concise description of what you expected to happen. -->

**To reproduce**
<!-- A minimal script to reproduce the issue. Links to Colab notebooks or similar tools are encouraged.
If the code is too long, feel free to put it in a public gist and link it in the issue: https://gist.github.com.
In short, we are going to copy-paste your code to run it and we expect to get the same result as you. -->

**Environment description**
<!-- Run `rk-transformers-cli env` and copy-paste the output here -->
<!--
- Operating system: 
- Rockchip Board: 
- Rockchip SoC: 
- RKNPU2 Driver version: 
- RKNN Runtime version: 
- RKNN Toolkit version: 
- Python version: 
- PyTorch version: 
- HuggingFace transformers version: 
- HuggingFace optimum version:
-->
